==> classiq_interface-0.3.0.tar.gz: classiq_interface-0.3.0/classiq_interface/server/routes.py <==
ROUTE_PREFIX = "/api/v1"
ANALYZER_DASHBOARD = "/analyzer"
ANALYZER_PREFIX = ROUTE_PREFIX + "/analyzer"
HYBRID_PREFIX = ROUTE_PREFIX + "/hybrid"
CHEMISTRY_PREFIX = ROUTE_PREFIX + "/chemistry"
EXECUTE_PREFIX = ROUTE_PREFIX + "/execute"
COMBINATORIAL_OPTIMIZATION_PREFIX = ROUTE_PREFIX + "/combinatorial_optimization"

TASKS_SUFFIX = "/tasks"

TASKS_GENERATE_SUFFIX = "/tasks/generate"
TASKS_SOLVE_SUFFIX = "/tasks/solve"
TASKS_WS_SOLVE_SUFFIX = "/ws/tasks/solve"
TASKS_OPERATOR_SUFFIX = "/tasks/operator"
TASKS_INITIAL_POINT_SUFFIX = "/tasks/initial_point"

EXECUTE_GENERATED_CIRCUIT_SUFFIX = "/tasks/generated_circuit"
EXECUTE_QUANTUM_PROGRAM_SUFFIX = "/tasks/quantum_program"
EXECUTE_HAMILTONIAN_MINIMIZATION_SUFFIX = "/tasks/hamiltonian_minimization"
EXECUTE_GENERATED_CIRCUIT_FULL_PATH = EXECUTE_PREFIX + EXECUTE_GENERATED_CIRCUIT_SUFFIX
EXECUTE_QUANTUM_PROGRAM_FULL_PATH = EXECUTE_PREFIX + EXECUTE_QUANTUM_PROGRAM_SUFFIX
EXECUTE_HAMILTONIAN_MINIMIZATION_FULL_PATH = (
    EXECUTE_PREFIX + EXECUTE_HAMILTONIAN_MINIMIZATION_SUFFIX
)

ANALYZER_FULL_PATH = ANALYZER_PREFIX + TASKS_SUFFIX
HYBRID_FULL_PATH = HYBRID_PREFIX + TASKS_SUFFIX
COMBINATORIAL_OPTIMIZATION_GENERATE_FULL_PATH = (
    COMBINATORIAL_OPTIMIZATION_PREFIX + TASKS_GENERATE_SUFFIX
)
COMBINATORIAL_OPTIMIZATION_SOLVE_FULL_PATH = (
    COMBINATORIAL_OPTIMIZATION_PREFIX + TASKS_SOLVE_SUFFIX
)
COMBINATORIAL_OPTIMIZATION_WS_SOLVE_FULL_PATH = (
    COMBINATORIAL_OPTIMIZATION_PREFIX + TASKS_WS_SOLVE_SUFFIX
)
COMBINATORIAL_OPTIMIZATION_OPERATOR_FULL_PATH = (
    COMBINATORIAL_OPTIMIZATION_PREFIX + TASKS_OPERATOR_SUFFIX
)
COMBINATORIAL_OPTIMIZATION_INITIAL_POINT_FULL_PATH = (
    COMBINATORIAL_OPTIMIZATION_PREFIX + TASKS_INITIAL_POINT_SUFFIX
)
GENERATE_CHEMISTRY_HAMILTONIAN_FULL_PATH = CHEMISTRY_PREFIX + TASKS_SUFFIX

==> classiq_interface-0.7.1.tar.gz: classiq_interface-0.7.1/classiq_interface/server/routes.py <==
ROUTE_PREFIX = "/api/v1"
ANALYZER_DASHBOARD = "/analyzer"
ANALYZER_PREFIX = ROUTE_PREFIX + "/analyzer"
CHEMISTRY_PREFIX = ROUTE_PREFIX + "/chemistry"
EXECUTE_PREFIX = ROUTE_PREFIX + "/execute"
COMBINATORIAL_OPTIMIZATION_PREFIX = ROUTE_PREFIX + "/combinatorial_optimization"

TASKS_SUFFIX = "/tasks"

TASKS_GENERATE_SUFFIX = "/tasks/generate"
TASKS_SOLVE_SUFFIX = "/tasks/solve"
TASKS_WS_SOLVE_SUFFIX = "/ws/tasks/solve"
TASKS_SOLVE_CLASSICALLY_SUFFIX = "/tasks/solve_classically"
TASKS_OPERATOR_SUFFIX = "/tasks/operator"
TASKS_OBJECTIVE_SUFFIX = "/tasks/objective"
TASKS_INITIAL_POINT_SUFFIX = "/tasks/initial_point"

EXECUTE_TASKS_FULL_PATH = EXECUTE_PREFIX + TASKS_SUFFIX

ANALYZER_FULL_PATH = ANALYZER_PREFIX + TASKS_SUFFIX
COMBINATORIAL_OPTIMIZATION_GENERATE_FULL_PATH = (
    COMBINATORIAL_OPTIMIZATION_PREFIX + TASKS_GENERATE_SUFFIX
)
COMBINATORIAL_OPTIMIZATION_SOLVE_FULL_PATH = (
    COMBINATORIAL_OPTIMIZATION_PREFIX + TASKS_SOLVE_SUFFIX
)
COMBINATORIAL_OPTIMIZATION_WS_SOLVE_FULL_PATH = (
    COMBINATORIAL_OPTIMIZATION_PREFIX + TASKS_WS_SOLVE_SUFFIX
)
COMBINATORIAL_OPTIMIZATION_SOLVE_CLASSICALLY_FULL_PATH = (
    COMBINATORIAL_OPTIMIZATION_PREFIX + TASKS_SOLVE_CLASSICALLY_SUFFIX
)
COMBINATORIAL_OPTIMIZATION_OPERATOR_FULL_PATH = (
    COMBINATORIAL_OPTIMIZATION_PREFIX + TASKS_OPERATOR_SUFFIX
)
COMBINATORIAL_OPTIMIZATION_OBJECTIVE_FULL_PATH = (
    COMBINATORIAL_OPTIMIZATION_PREFIX + TASKS_OBJECTIVE_SUFFIX
)
COMBINATORIAL_OPTIMIZATION_INITIAL_POINT_FULL_PATH = (
    COMBINATORIAL_OPTIMIZATION_PREFIX + TASKS_INITIAL_POINT_SUFFIX
)
GENERATE_CHEMISTRY_HAMILTONIAN_FULL_PATH = CHEMISTRY_PREFIX + TASKS_SUFFIX
